ModuleGraph

Trait ModuleGraph 

pub trait ModuleGraph {
    // Required methods
    fn register_providers(registry: &mut ProviderRegistry);
    fn register_controllers(
        router: Router,
        registry: &ProviderRegistry,
    ) -> Router;
}
Testing-oriented module traversal API.

Unlike Module::build, implementations are expected to register all providers and controllers from the import graph into a shared registry/router, so tests can apply overrides before controllers are registered.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors